import { computed, defineComponent, h, mergeProps, reactive, ref, toRefs, watchEffect } from "vue";
import { reactiveOmit, useListeners, usePrevious, useSize } from "@oku-ui/use-composable";
import { isIndeterminate } from "./utils.mjs";
import { CHECKBOX_BUBBLE_INPUT_NAME, bubbleInputProps } from "./props.mjs";
const bubbleInput = defineComponent({
  name: CHECKBOX_BUBBLE_INPUT_NAME,
  inheritAttrs: false,
  props: {
    ...bubbleInputProps.props
  },
  emits: {
    ...bubbleInputProps.emits
  },
  setup(props, { attrs }) {
    const {
      checked,
      bubbles,
      control,
      ...inputProps
    } = toRefs(props);
    const _reactive = reactive(inputProps);
    const otherProps = reactiveOmit(_reactive, (key, _value) => key === void 0);
    const emits = useListeners();
    const inputRef = ref(null);
    const prevChecked = usePrevious(checked);
    const controlSize = computed(() => useSize(control));
    watchEffect(() => {
      const input = inputRef.value;
      const inputProto = window.HTMLInputElement.prototype;
      const descriptor = Object.getOwnPropertyDescriptor(inputProto, "checked");
      const setChecked = descriptor.set;
      if (prevChecked.value !== checked.value && setChecked) {
        const event = new Event("click", { bubbles: bubbles.value });
        input.indeterminate = isIndeterminate(checked.value);
        setChecked.call(input, isIndeterminate(checked.value) ? false : checked);
        input.dispatchEvent(event);
      }
    });
    return () => h("input", {
      "type": "checkbox",
      "aria-hidden": true,
      "defaultChecked": isIndeterminate(checked.value) ? false : checked.value,
      ...mergeProps(attrs, otherProps, emits),
      "tabIndex": -1,
      "ref": inputRef,
      "style": {
        ...attrs.style,
        ...controlSize.value,
        position: "absolute",
        pointerEvents: "none",
        opacity: 0,
        margin: "0px"
      }
    });
  }
});
export const OkuBubbleInput = bubbleInput;
