import { computed, defineComponent, h, mergeProps, reactive, toRefs } from "vue";
import { reactiveOmit, useForwardRef, useListeners } from "@oku-ui/use-composable";
import { Primitive } from "@oku-ui/primitive";
import { OkuPresence } from "@oku-ui/presence";
import { getState, isIndeterminate } from "./utils.mjs";
import { CHECKBOX_INDICATOR_NAME, checkboxIndicatorProps, scopeCheckboxProps, useCheckboxInject } from "./props.mjs";
const checkboxIndicator = defineComponent({
  name: CHECKBOX_INDICATOR_NAME,
  props: {
    ...checkboxIndicatorProps.props,
    ...scopeCheckboxProps
  },
  emits: {
    ...checkboxIndicatorProps.emits
  },
  setup(props, { attrs, slots }) {
    const {
      scopeOkuCheckbox,
      forceMount,
      ...indicatorProps
    } = toRefs(props);
    const _reactive = reactive(indicatorProps);
    const otherProps = reactiveOmit(_reactive, (key, _value) => key === void 0);
    const forwardedRef = useForwardRef();
    const emits = useListeners();
    const inject = useCheckboxInject(CHECKBOX_INDICATOR_NAME, scopeOkuCheckbox.value);
    return () => h(OkuPresence, {
      present: computed(() => forceMount.value || isIndeterminate(inject.state.value) || inject.state.value === true).value
    }, () => h(Primitive.span, {
      "data-state": computed(() => getState(inject.state.value)).value,
      "data-disabled": inject.disabled?.value ? "" : void 0,
      ...mergeProps(attrs, otherProps, emits),
      "ref": forwardedRef,
      "style": { pointerEvents: "none", ...attrs.style }
    }, () => slots.default?.()));
  }
});
export const OkuCheckboxIndicator = checkboxIndicator;
