import type { PropType, Ref } from 'vue';
import type { Scope } from '@oku-ui/provide';
import type { OkuElement, PrimitiveProps } from '@oku-ui/primitive';
export type ScopeCheckbox<T> = T & {
    scopeOkuCheckbox?: Scope;
};
export declare const scopeCheckboxProps: {
    scopeOkuCheckbox: {
        type: PropType<Scope<any>>;
        required: boolean;
    };
};
export declare const CHECKBOX_NAME = "OkuCheckbox";
export declare const CHECKBOX_INDICATOR_NAME = "OkuCheckboxIndicator";
export declare const CHECKBOX_BUBBLE_INPUT_NAME = "OkuBubbleInput";
export type CheckboxNativeElement = Omit<OkuElement<'button', true>, 'checked' | 'defaultChecked'>;
export type CheckboxElement = HTMLButtonElement;
export declare const createCheckboxProvider: <ProvideValueType extends object | null>(rootComponentName: string, defaultValue?: ProvideValueType | undefined) => readonly [(props: ProvideValueType & {
    scope: Scope<ProvideValueType>;
}) => void, (consumerName: string, scope: Scope<ProvideValueType | undefined>) => ProvideValueType], createCheckboxScope: import("@oku-ui/provide/dist/createProvide").CreateScope;
export declare const checkboxProvider: (props: CheckboxInjectValue & {
    scope: Scope<CheckboxInjectValue>;
}) => void, useCheckboxInject: (consumerName: string, scope: Scope<CheckboxInjectValue | undefined>) => CheckboxInjectValue;
export type CheckedState = boolean | 'indeterminate';
export type CheckboxInjectValue = {
    state: Ref<CheckedState>;
    disabled?: Ref<boolean | undefined>;
};
export interface CheckboxProps extends PrimitiveProps {
    checked?: CheckedState;
    defaultChecked?: CheckedState;
    required?: boolean;
    name?: string;
    disabled?: boolean;
    value?: string;
    modelValue?: CheckedState;
}
export type CheckboxEmits = {
    'update:modelValue': [checked: CheckedState];
    'checkedChange': [checked: CheckedState];
    'keydown': [event: KeyboardEvent];
    'click': [event: MouseEvent];
};
export declare const checkboxProps: {
    props: {
        asChild: BooleanConstructor;
        modelValue: {
            type: PropType<CheckedState | undefined>;
            default: undefined;
        };
        checked: {
            type: PropType<CheckedState | undefined>;
            default: undefined;
        };
        defaultChecked: {
            type: PropType<CheckedState | undefined>;
            default: undefined;
        };
        required: {
            type: PropType<boolean | undefined>;
        };
        name: {
            type: PropType<string | undefined>;
        };
        disabled: {
            type: PropType<boolean | undefined>;
        };
        value: {
            type: PropType<string | undefined>;
            default: string;
        };
    };
    emits: {
        'update:modelValue': (checked: CheckboxEmits['update:modelValue'][0]) => boolean;
        checkedChange: (checked: CheckboxEmits['checkedChange'][0]) => boolean;
        keydown: (event: CheckboxEmits['keydown'][0]) => boolean;
        click: (event: CheckboxEmits['click'][0]) => boolean;
    };
};
export type CheckboxIndicatorNativeElement = OkuElement<'span'>;
export type CheckboxIndicatorElement = HTMLSpanElement;
export interface CheckboxIndicatorProps extends PrimitiveProps {
    forceMount?: true;
}
export declare const checkboxIndicatorProps: {
    props: {
        asChild: BooleanConstructor;
        forceMount: {
            type: PropType<true | undefined>;
            default: undefined;
        };
    };
    emits: {};
};
export type BubbleInputNativeElement = Omit<OkuElement<'input', true>, 'checked'>;
export type BubbleInputElement = HTMLInputElement;
export interface BubbleInputProps {
    checked: CheckedState;
    control: HTMLElement | null;
    bubbles: boolean;
}
export declare const bubbleInputProps: {
    props: {
        checked: {
            type: PropType<CheckedState>;
            required: boolean;
        };
        control: {
            type: PropType<HTMLElement | null>;
            default: null;
            required: boolean;
        };
        bubbles: {
            type: PropType<boolean>;
            default: boolean;
            required: boolean;
        };
    };
    emits: {};
};
